# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['ProviderArgs', 'Provider']

@pulumi.input_type
class ProviderArgs:
    def __init__(__self__, *,
                 identifier: pulumi.Input[_builtins.str],
                 spec: pulumi.Input['ProviderSpecArgs'],
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a Provider resource.
        :param pulumi.Input[_builtins.str] identifier: The identifier of the provider entity.
        :param pulumi.Input['ProviderSpecArgs'] spec: Contains parameters related to the provider entity.
        :param pulumi.Input[_builtins.str] description: The description of the provider entity.
        :param pulumi.Input[_builtins.str] name: The name of the provider entity.
        """
        pulumi.set(__self__, "identifier", identifier)
        pulumi.set(__self__, "spec", spec)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> pulumi.Input[_builtins.str]:
        """
        The identifier of the provider entity.
        """
        return pulumi.get(self, "identifier")

    @identifier.setter
    def identifier(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "identifier", value)

    @_builtins.property
    @pulumi.getter
    def spec(self) -> pulumi.Input['ProviderSpecArgs']:
        """
        Contains parameters related to the provider entity.
        """
        return pulumi.get(self, "spec")

    @spec.setter
    def spec(self, value: pulumi.Input['ProviderSpecArgs']):
        pulumi.set(self, "spec", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The description of the provider entity.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the provider entity.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)


@pulumi.input_type
class _ProviderState:
    def __init__(__self__, *,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 last_modified_at: Optional[pulumi.Input[_builtins.int]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 spec: Optional[pulumi.Input['ProviderSpecArgs']] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering Provider resources.
        :param pulumi.Input[_builtins.str] description: The description of the provider entity.
        :param pulumi.Input[_builtins.str] identifier: The identifier of the provider entity.
        :param pulumi.Input[_builtins.int] last_modified_at: The last modified time of the provider entity.
        :param pulumi.Input[_builtins.str] name: The name of the provider entity.
        :param pulumi.Input['ProviderSpecArgs'] spec: Contains parameters related to the provider entity.
        :param pulumi.Input[_builtins.str] type: The type of the provider entity.
        """
        if description is not None:
            pulumi.set(__self__, "description", description)
        if identifier is not None:
            pulumi.set(__self__, "identifier", identifier)
        if last_modified_at is not None:
            pulumi.set(__self__, "last_modified_at", last_modified_at)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if spec is not None:
            pulumi.set(__self__, "spec", spec)
        if type is not None:
            pulumi.set(__self__, "type", type)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The description of the provider entity.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The identifier of the provider entity.
        """
        return pulumi.get(self, "identifier")

    @identifier.setter
    def identifier(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "identifier", value)

    @_builtins.property
    @pulumi.getter(name="lastModifiedAt")
    def last_modified_at(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The last modified time of the provider entity.
        """
        return pulumi.get(self, "last_modified_at")

    @last_modified_at.setter
    def last_modified_at(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "last_modified_at", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the provider entity.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def spec(self) -> Optional[pulumi.Input['ProviderSpecArgs']]:
        """
        Contains parameters related to the provider entity.
        """
        return pulumi.get(self, "spec")

    @spec.setter
    def spec(self, value: Optional[pulumi.Input['ProviderSpecArgs']]):
        pulumi.set(self, "spec", value)

    @_builtins.property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The type of the provider entity.
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "type", value)


@pulumi.type_token("harness:platform/provider:Provider")
class Provider(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 spec: Optional[pulumi.Input[Union['ProviderSpecArgs', 'ProviderSpecArgsDict']]] = None,
                 __props__=None):
        """
        Resource for creating a Harness Provider.

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] description: The description of the provider entity.
        :param pulumi.Input[_builtins.str] identifier: The identifier of the provider entity.
        :param pulumi.Input[_builtins.str] name: The name of the provider entity.
        :param pulumi.Input[Union['ProviderSpecArgs', 'ProviderSpecArgsDict']] spec: Contains parameters related to the provider entity.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ProviderArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Resource for creating a Harness Provider.

        :param str resource_name: The name of the resource.
        :param ProviderArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ProviderArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 spec: Optional[pulumi.Input[Union['ProviderSpecArgs', 'ProviderSpecArgsDict']]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ProviderArgs.__new__(ProviderArgs)

            __props__.__dict__["description"] = description
            if identifier is None and not opts.urn:
                raise TypeError("Missing required property 'identifier'")
            __props__.__dict__["identifier"] = identifier
            __props__.__dict__["name"] = name
            if spec is None and not opts.urn:
                raise TypeError("Missing required property 'spec'")
            __props__.__dict__["spec"] = spec
            __props__.__dict__["last_modified_at"] = None
            __props__.__dict__["type"] = None
        super(Provider, __self__).__init__(
            'harness:platform/provider:Provider',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            identifier: Optional[pulumi.Input[_builtins.str]] = None,
            last_modified_at: Optional[pulumi.Input[_builtins.int]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            spec: Optional[pulumi.Input[Union['ProviderSpecArgs', 'ProviderSpecArgsDict']]] = None,
            type: Optional[pulumi.Input[_builtins.str]] = None) -> 'Provider':
        """
        Get an existing Provider resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] description: The description of the provider entity.
        :param pulumi.Input[_builtins.str] identifier: The identifier of the provider entity.
        :param pulumi.Input[_builtins.int] last_modified_at: The last modified time of the provider entity.
        :param pulumi.Input[_builtins.str] name: The name of the provider entity.
        :param pulumi.Input[Union['ProviderSpecArgs', 'ProviderSpecArgsDict']] spec: Contains parameters related to the provider entity.
        :param pulumi.Input[_builtins.str] type: The type of the provider entity.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ProviderState.__new__(_ProviderState)

        __props__.__dict__["description"] = description
        __props__.__dict__["identifier"] = identifier
        __props__.__dict__["last_modified_at"] = last_modified_at
        __props__.__dict__["name"] = name
        __props__.__dict__["spec"] = spec
        __props__.__dict__["type"] = type
        return Provider(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The description of the provider entity.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> pulumi.Output[_builtins.str]:
        """
        The identifier of the provider entity.
        """
        return pulumi.get(self, "identifier")

    @_builtins.property
    @pulumi.getter(name="lastModifiedAt")
    def last_modified_at(self) -> pulumi.Output[_builtins.int]:
        """
        The last modified time of the provider entity.
        """
        return pulumi.get(self, "last_modified_at")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the provider entity.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def spec(self) -> pulumi.Output['outputs.ProviderSpec']:
        """
        Contains parameters related to the provider entity.
        """
        return pulumi.get(self, "spec")

    @_builtins.property
    @pulumi.getter
    def type(self) -> pulumi.Output[_builtins.str]:
        """
        The type of the provider entity.
        """
        return pulumi.get(self, "type")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetCurrentUserResult',
    'AwaitableGetCurrentUserResult',
    'get_current_user',
    'get_current_user_output',
]

@pulumi.output_type
class GetCurrentUserResult:
    """
    A collection of values returned by getCurrentUser.
    """
    def __init__(__self__, admin=None, billing_frequency=None, default_account_id=None, edition=None, email=None, email_verified=None, id=None, intent=None, is_two_factor_auth_enabled=None, locked=None, name=None, signup_action=None, token=None, uuid=None):
        if admin and not isinstance(admin, bool):
            raise TypeError("Expected argument 'admin' to be a bool")
        pulumi.set(__self__, "admin", admin)
        if billing_frequency and not isinstance(billing_frequency, str):
            raise TypeError("Expected argument 'billing_frequency' to be a str")
        pulumi.set(__self__, "billing_frequency", billing_frequency)
        if default_account_id and not isinstance(default_account_id, str):
            raise TypeError("Expected argument 'default_account_id' to be a str")
        pulumi.set(__self__, "default_account_id", default_account_id)
        if edition and not isinstance(edition, str):
            raise TypeError("Expected argument 'edition' to be a str")
        pulumi.set(__self__, "edition", edition)
        if email and not isinstance(email, str):
            raise TypeError("Expected argument 'email' to be a str")
        pulumi.set(__self__, "email", email)
        if email_verified and not isinstance(email_verified, bool):
            raise TypeError("Expected argument 'email_verified' to be a bool")
        pulumi.set(__self__, "email_verified", email_verified)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if intent and not isinstance(intent, str):
            raise TypeError("Expected argument 'intent' to be a str")
        pulumi.set(__self__, "intent", intent)
        if is_two_factor_auth_enabled and not isinstance(is_two_factor_auth_enabled, bool):
            raise TypeError("Expected argument 'is_two_factor_auth_enabled' to be a bool")
        pulumi.set(__self__, "is_two_factor_auth_enabled", is_two_factor_auth_enabled)
        if locked and not isinstance(locked, bool):
            raise TypeError("Expected argument 'locked' to be a bool")
        pulumi.set(__self__, "locked", locked)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if signup_action and not isinstance(signup_action, str):
            raise TypeError("Expected argument 'signup_action' to be a str")
        pulumi.set(__self__, "signup_action", signup_action)
        if token and not isinstance(token, str):
            raise TypeError("Expected argument 'token' to be a str")
        pulumi.set(__self__, "token", token)
        if uuid and not isinstance(uuid, str):
            raise TypeError("Expected argument 'uuid' to be a str")
        pulumi.set(__self__, "uuid", uuid)

    @_builtins.property
    @pulumi.getter
    def admin(self) -> _builtins.bool:
        """
        Whether the user is an administrator.
        """
        return pulumi.get(self, "admin")

    @_builtins.property
    @pulumi.getter(name="billingFrequency")
    def billing_frequency(self) -> _builtins.str:
        """
        Billing frequency of the user.
        """
        return pulumi.get(self, "billing_frequency")

    @_builtins.property
    @pulumi.getter(name="defaultAccountId")
    def default_account_id(self) -> _builtins.str:
        """
        Default account ID of the user.
        """
        return pulumi.get(self, "default_account_id")

    @_builtins.property
    @pulumi.getter
    def edition(self) -> _builtins.str:
        """
        Edition of the platform being used.
        """
        return pulumi.get(self, "edition")

    @_builtins.property
    @pulumi.getter
    def email(self) -> _builtins.str:
        """
        Email address of the user.
        """
        return pulumi.get(self, "email")

    @_builtins.property
    @pulumi.getter(name="emailVerified")
    def email_verified(self) -> _builtins.bool:
        """
        Whether the user's email address has been verified.
        """
        return pulumi.get(self, "email_verified")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def intent(self) -> _builtins.str:
        """
        Intent of the user.
        """
        return pulumi.get(self, "intent")

    @_builtins.property
    @pulumi.getter(name="isTwoFactorAuthEnabled")
    def is_two_factor_auth_enabled(self) -> _builtins.bool:
        """
        Whether 2FA is enabled for the user.
        """
        return pulumi.get(self, "is_two_factor_auth_enabled")

    @_builtins.property
    @pulumi.getter
    def locked(self) -> _builtins.bool:
        """
        Whether or not the user account is locked.
        """
        return pulumi.get(self, "locked")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        Name of the user.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="signupAction")
    def signup_action(self) -> _builtins.str:
        """
        Signup action of the user.
        """
        return pulumi.get(self, "signup_action")

    @_builtins.property
    @pulumi.getter
    def token(self) -> _builtins.str:
        """
        Token used to authenticate the user.
        """
        return pulumi.get(self, "token")

    @_builtins.property
    @pulumi.getter
    def uuid(self) -> _builtins.str:
        """
        Unique identifier of the user.
        """
        return pulumi.get(self, "uuid")


class AwaitableGetCurrentUserResult(GetCurrentUserResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetCurrentUserResult(
            admin=self.admin,
            billing_frequency=self.billing_frequency,
            default_account_id=self.default_account_id,
            edition=self.edition,
            email=self.email,
            email_verified=self.email_verified,
            id=self.id,
            intent=self.intent,
            is_two_factor_auth_enabled=self.is_two_factor_auth_enabled,
            locked=self.locked,
            name=self.name,
            signup_action=self.signup_action,
            token=self.token,
            uuid=self.uuid)


def get_current_user(opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetCurrentUserResult:
    """
    Data source for retrieving the current user based on the API key.
    """
    __args__ = dict()
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('harness:platform/getCurrentUser:getCurrentUser', __args__, opts=opts, typ=GetCurrentUserResult).value

    return AwaitableGetCurrentUserResult(
        admin=pulumi.get(__ret__, 'admin'),
        billing_frequency=pulumi.get(__ret__, 'billing_frequency'),
        default_account_id=pulumi.get(__ret__, 'default_account_id'),
        edition=pulumi.get(__ret__, 'edition'),
        email=pulumi.get(__ret__, 'email'),
        email_verified=pulumi.get(__ret__, 'email_verified'),
        id=pulumi.get(__ret__, 'id'),
        intent=pulumi.get(__ret__, 'intent'),
        is_two_factor_auth_enabled=pulumi.get(__ret__, 'is_two_factor_auth_enabled'),
        locked=pulumi.get(__ret__, 'locked'),
        name=pulumi.get(__ret__, 'name'),
        signup_action=pulumi.get(__ret__, 'signup_action'),
        token=pulumi.get(__ret__, 'token'),
        uuid=pulumi.get(__ret__, 'uuid'))
def get_current_user_output(opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetCurrentUserResult]:
    """
    Data source for retrieving the current user based on the API key.
    """
    __args__ = dict()
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('harness:platform/getCurrentUser:getCurrentUser', __args__, opts=opts, typ=GetCurrentUserResult)
    return __ret__.apply(lambda __response__: GetCurrentUserResult(
        admin=pulumi.get(__response__, 'admin'),
        billing_frequency=pulumi.get(__response__, 'billing_frequency'),
        default_account_id=pulumi.get(__response__, 'default_account_id'),
        edition=pulumi.get(__response__, 'edition'),
        email=pulumi.get(__response__, 'email'),
        email_verified=pulumi.get(__response__, 'email_verified'),
        id=pulumi.get(__response__, 'id'),
        intent=pulumi.get(__response__, 'intent'),
        is_two_factor_auth_enabled=pulumi.get(__response__, 'is_two_factor_auth_enabled'),
        locked=pulumi.get(__response__, 'locked'),
        name=pulumi.get(__response__, 'name'),
        signup_action=pulumi.get(__response__, 'signup_action'),
        token=pulumi.get(__response__, 'token'),
        uuid=pulumi.get(__response__, 'uuid')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetDashboardFoldersResult',
    'AwaitableGetDashboardFoldersResult',
    'get_dashboard_folders',
    'get_dashboard_folders_output',
]

@pulumi.output_type
class GetDashboardFoldersResult:
    """
    A collection of values returned by getDashboardFolders.
    """
    def __init__(__self__, created_at=None, description=None, id=None, identifier=None, name=None, tags=None):
        if created_at and not isinstance(created_at, str):
            raise TypeError("Expected argument 'created_at' to be a str")
        pulumi.set(__self__, "created_at", created_at)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if identifier and not isinstance(identifier, str):
            raise TypeError("Expected argument 'identifier' to be a str")
        pulumi.set(__self__, "identifier", identifier)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> _builtins.str:
        """
        Created DateTime of the folder.
        """
        return pulumi.get(self, "created_at")

    @_builtins.property
    @pulumi.getter
    def description(self) -> _builtins.str:
        """
        Description of the resource.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        Identifier of the folder.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> Optional[_builtins.str]:
        """
        Unique identifier of the resource.
        """
        return pulumi.get(self, "identifier")

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[_builtins.str]:
        """
        Name of the resource.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Sequence[_builtins.str]:
        """
        Tags to associate with the resource.
        """
        return pulumi.get(self, "tags")


class AwaitableGetDashboardFoldersResult(GetDashboardFoldersResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetDashboardFoldersResult(
            created_at=self.created_at,
            description=self.description,
            id=self.id,
            identifier=self.identifier,
            name=self.name,
            tags=self.tags)


def get_dashboard_folders(id: Optional[_builtins.str] = None,
                          identifier: Optional[_builtins.str] = None,
                          name: Optional[_builtins.str] = None,
                          opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetDashboardFoldersResult:
    """
    Data source for retrieving a Harness Dashboard Folder.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_harness as harness

    folder = harness.platform.get_dashboard_folders(id="id")
    ```


    :param _builtins.str id: Identifier of the folder.
    :param _builtins.str identifier: Unique identifier of the resource.
    :param _builtins.str name: Name of the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['identifier'] = identifier
    __args__['name'] = name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('harness:platform/getDashboardFolders:getDashboardFolders', __args__, opts=opts, typ=GetDashboardFoldersResult).value

    return AwaitableGetDashboardFoldersResult(
        created_at=pulumi.get(__ret__, 'created_at'),
        description=pulumi.get(__ret__, 'description'),
        id=pulumi.get(__ret__, 'id'),
        identifier=pulumi.get(__ret__, 'identifier'),
        name=pulumi.get(__ret__, 'name'),
        tags=pulumi.get(__ret__, 'tags'))
def get_dashboard_folders_output(id: Optional[pulumi.Input[_builtins.str]] = None,
                                 identifier: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                 name: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                 opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetDashboardFoldersResult]:
    """
    Data source for retrieving a Harness Dashboard Folder.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_harness as harness

    folder = harness.platform.get_dashboard_folders(id="id")
    ```


    :param _builtins.str id: Identifier of the folder.
    :param _builtins.str identifier: Unique identifier of the resource.
    :param _builtins.str name: Name of the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['identifier'] = identifier
    __args__['name'] = name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('harness:platform/getDashboardFolders:getDashboardFolders', __args__, opts=opts, typ=GetDashboardFoldersResult)
    return __ret__.apply(lambda __response__: GetDashboardFoldersResult(
        created_at=pulumi.get(__response__, 'created_at'),
        description=pulumi.get(__response__, 'description'),
        id=pulumi.get(__response__, 'id'),
        identifier=pulumi.get(__response__, 'identifier'),
        name=pulumi.get(__response__, 'name'),
        tags=pulumi.get(__response__, 'tags')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['GitopsAppProjectArgs', 'GitopsAppProject']

@pulumi.input_type
class GitopsAppProjectArgs:
    def __init__(__self__, *,
                 agent_id: pulumi.Input[_builtins.str],
                 projects: pulumi.Input[Sequence[pulumi.Input['GitopsAppProjectProjectArgs']]],
                 account_id: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 query_name: Optional[pulumi.Input[_builtins.str]] = None,
                 upsert: Optional[pulumi.Input[_builtins.bool]] = None):
        """
        The set of arguments for constructing a GitopsAppProject resource.
        :param pulumi.Input[_builtins.str] agent_id: Agent identifier of the agent where argo project will exist (include scope prefix)
        :param pulumi.Input[Sequence[pulumi.Input['GitopsAppProjectProjectArgs']]] projects: GitOps project configuration.
        :param pulumi.Input[_builtins.str] account_id: Account identifier of the GitOps Agent where argo project will exist.
        :param pulumi.Input[_builtins.str] org_id: Org identifier of the GitOps Agent where argo project is to be created.
        :param pulumi.Input[_builtins.str] project_id: Project identifier of the Gitops Agent where argo project is to be created.
        :param pulumi.Input[_builtins.str] query_name: Identifier for the GitOps Argo project.
        :param pulumi.Input[_builtins.bool] upsert: Indicates if the argo project should be updated if existing and inserted if not.
        """
        pulumi.set(__self__, "agent_id", agent_id)
        pulumi.set(__self__, "projects", projects)
        if account_id is not None:
            warnings.warn("""This field is deprecated and will be removed in a future release.""", DeprecationWarning)
            pulumi.log.warn("""account_id is deprecated: This field is deprecated and will be removed in a future release.""")
        if account_id is not None:
            pulumi.set(__self__, "account_id", account_id)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if query_name is not None:
            pulumi.set(__self__, "query_name", query_name)
        if upsert is not None:
            pulumi.set(__self__, "upsert", upsert)

    @_builtins.property
    @pulumi.getter(name="agentId")
    def agent_id(self) -> pulumi.Input[_builtins.str]:
        """
        Agent identifier of the agent where argo project will exist (include scope prefix)
        """
        return pulumi.get(self, "agent_id")

    @agent_id.setter
    def agent_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "agent_id", value)

    @_builtins.property
    @pulumi.getter
    def projects(self) -> pulumi.Input[Sequence[pulumi.Input['GitopsAppProjectProjectArgs']]]:
        """
        GitOps project configuration.
        """
        return pulumi.get(self, "projects")

    @projects.setter
    def projects(self, value: pulumi.Input[Sequence[pulumi.Input['GitopsAppProjectProjectArgs']]]):
        pulumi.set(self, "projects", value)

    @_builtins.property
    @pulumi.getter(name="accountId")
    @_utilities.deprecated("""This field is deprecated and will be removed in a future release.""")
    def account_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Account identifier of the GitOps Agent where argo project will exist.
        """
        return pulumi.get(self, "account_id")

    @account_id.setter
    def account_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "account_id", value)

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Org identifier of the GitOps Agent where argo project is to be created.
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "org_id", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Project identifier of the Gitops Agent where argo project is to be created.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter(name="queryName")
    def query_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Identifier for the GitOps Argo project.
        """
        return pulumi.get(self, "query_name")

    @query_name.setter
    def query_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "query_name", value)

    @_builtins.property
    @pulumi.getter
    def upsert(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Indicates if the argo project should be updated if existing and inserted if not.
        """
        return pulumi.get(self, "upsert")

    @upsert.setter
    def upsert(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "upsert", value)


@pulumi.input_type
class _GitopsAppProjectState:
    def __init__(__self__, *,
                 account_id: Optional[pulumi.Input[_builtins.str]] = None,
                 agent_id: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 projects: Optional[pulumi.Input[Sequence[pulumi.Input['GitopsAppProjectProjectArgs']]]] = None,
                 query_name: Optional[pulumi.Input[_builtins.str]] = None,
                 upsert: Optional[pulumi.Input[_builtins.bool]] = None):
        """
        Input properties used for looking up and filtering GitopsAppProject resources.
        :param pulumi.Input[_builtins.str] account_id: Account identifier of the GitOps Agent where argo project will exist.
        :param pulumi.Input[_builtins.str] agent_id: Agent identifier of the agent where argo project will exist (include scope prefix)
        :param pulumi.Input[_builtins.str] org_id: Org identifier of the GitOps Agent where argo project is to be created.
        :param pulumi.Input[_builtins.str] project_id: Project identifier of the Gitops Agent where argo project is to be created.
        :param pulumi.Input[Sequence[pulumi.Input['GitopsAppProjectProjectArgs']]] projects: GitOps project configuration.
        :param pulumi.Input[_builtins.str] query_name: Identifier for the GitOps Argo project.
        :param pulumi.Input[_builtins.bool] upsert: Indicates if the argo project should be updated if existing and inserted if not.
        """
        if account_id is not None:
            warnings.warn("""This field is deprecated and will be removed in a future release.""", DeprecationWarning)
            pulumi.log.warn("""account_id is deprecated: This field is deprecated and will be removed in a future release.""")
        if account_id is not None:
            pulumi.set(__self__, "account_id", account_id)
        if agent_id is not None:
            pulumi.set(__self__, "agent_id", agent_id)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if projects is not None:
            pulumi.set(__self__, "projects", projects)
        if query_name is not None:
            pulumi.set(__self__, "query_name", query_name)
        if upsert is not None:
            pulumi.set(__self__, "upsert", upsert)

    @_builtins.property
    @pulumi.getter(name="accountId")
    @_utilities.deprecated("""This field is deprecated and will be removed in a future release.""")
    def account_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Account identifier of the GitOps Agent where argo project will exist.
        """
        return pulumi.get(self, "account_id")

    @account_id.setter
    def account_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "account_id", value)

    @_builtins.property
    @pulumi.getter(name="agentId")
    def agent_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Agent identifier of the agent where argo project will exist (include scope prefix)
        """
        return pulumi.get(self, "agent_id")

    @agent_id.setter
    def agent_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "agent_id", value)

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Org identifier of the GitOps Agent where argo project is to be created.
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "org_id", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Project identifier of the Gitops Agent where argo project is to be created.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter
    def projects(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['GitopsAppProjectProjectArgs']]]]:
        """
        GitOps project configuration.
        """
        return pulumi.get(self, "projects")

    @projects.setter
    def projects(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['GitopsAppProjectProjectArgs']]]]):
        pulumi.set(self, "projects", value)

    @_builtins.property
    @pulumi.getter(name="queryName")
    def query_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Identifier for the GitOps Argo project.
        """
        return pulumi.get(self, "query_name")

    @query_name.setter
    def query_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "query_name", value)

    @_builtins.property
    @pulumi.getter
    def upsert(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Indicates if the argo project should be updated if existing and inserted if not.
        """
        return pulumi.get(self, "upsert")

    @upsert.setter
    def upsert(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "upsert", value)


@pulumi.type_token("harness:platform/gitopsAppProject:GitopsAppProject")
class GitopsAppProject(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 account_id: Optional[pulumi.Input[_builtins.str]] = None,
                 agent_id: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 projects: Optional[pulumi.Input[Sequence[pulumi.Input[Union['GitopsAppProjectProjectArgs', 'GitopsAppProjectProjectArgsDict']]]]] = None,
                 query_name: Optional[pulumi.Input[_builtins.str]] = None,
                 upsert: Optional[pulumi.Input[_builtins.bool]] = None,
                 __props__=None):
        """
        ## Example Usage

        ## Import

        The `pulumi import` command can be used, for example:

        Import gitOps project with account level agent

        ```sh
        $ pulumi import harness:platform/gitopsAppProject:GitopsAppProject example <agent_id>/<app_proj_name>
        ```

        Import gitOps project with org level agent

        ```sh
        $ pulumi import harness:platform/gitopsAppProject:GitopsAppProject example <organization_id>/<agent_id>/<app_proj_name>
        ```

        Import gitOps project with project level agent

        ```sh
        $ pulumi import harness:platform/gitopsAppProject:GitopsAppProject example <organization_id>/<project_id>/<agent_id>/<app_proj_name>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] account_id: Account identifier of the GitOps Agent where argo project will exist.
        :param pulumi.Input[_builtins.str] agent_id: Agent identifier of the agent where argo project will exist (include scope prefix)
        :param pulumi.Input[_builtins.str] org_id: Org identifier of the GitOps Agent where argo project is to be created.
        :param pulumi.Input[_builtins.str] project_id: Project identifier of the Gitops Agent where argo project is to be created.
        :param pulumi.Input[Sequence[pulumi.Input[Union['GitopsAppProjectProjectArgs', 'GitopsAppProjectProjectArgsDict']]]] projects: GitOps project configuration.
        :param pulumi.Input[_builtins.str] query_name: Identifier for the GitOps Argo project.
        :param pulumi.Input[_builtins.bool] upsert: Indicates if the argo project should be updated if existing and inserted if not.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: GitopsAppProjectArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Example Usage

        ## Import

        The `pulumi import` command can be used, for example:

        Import gitOps project with account level agent

        ```sh
        $ pulumi import harness:platform/gitopsAppProject:GitopsAppProject example <agent_id>/<app_proj_name>
        ```

        Import gitOps project with org level agent

        ```sh
        $ pulumi import harness:platform/gitopsAppProject:GitopsAppProject example <organization_id>/<agent_id>/<app_proj_name>
        ```

        Import gitOps project with project level agent

        ```sh
        $ pulumi import harness:platform/gitopsAppProject:GitopsAppProject example <organization_id>/<project_id>/<agent_id>/<app_proj_name>
        ```

        :param str resource_name: The name of the resource.
        :param GitopsAppProjectArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(GitopsAppProjectArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 account_id: Optional[pulumi.Input[_builtins.str]] = None,
                 agent_id: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 projects: Optional[pulumi.Input[Sequence[pulumi.Input[Union['GitopsAppProjectProjectArgs', 'GitopsAppProjectProjectArgsDict']]]]] = None,
                 query_name: Optional[pulumi.Input[_builtins.str]] = None,
                 upsert: Optional[pulumi.Input[_builtins.bool]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = GitopsAppProjectArgs.__new__(GitopsAppProjectArgs)

            __props__.__dict__["account_id"] = account_id
            if agent_id is None and not opts.urn:
                raise TypeError("Missing required property 'agent_id'")
            __props__.__dict__["agent_id"] = agent_id
            __props__.__dict__["org_id"] = org_id
            __props__.__dict__["project_id"] = project_id
            if projects is None and not opts.urn:
                raise TypeError("Missing required property 'projects'")
            __props__.__dict__["projects"] = projects
            __props__.__dict__["query_name"] = query_name
            __props__.__dict__["upsert"] = upsert
        super(GitopsAppProject, __self__).__init__(
            'harness:platform/gitopsAppProject:GitopsAppProject',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            account_id: Optional[pulumi.Input[_builtins.str]] = None,
            agent_id: Optional[pulumi.Input[_builtins.str]] = None,
            org_id: Optional[pulumi.Input[_builtins.str]] = None,
            project_id: Optional[pulumi.Input[_builtins.str]] = None,
            projects: Optional[pulumi.Input[Sequence[pulumi.Input[Union['GitopsAppProjectProjectArgs', 'GitopsAppProjectProjectArgsDict']]]]] = None,
            query_name: Optional[pulumi.Input[_builtins.str]] = None,
            upsert: Optional[pulumi.Input[_builtins.bool]] = None) -> 'GitopsAppProject':
        """
        Get an existing GitopsAppProject resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] account_id: Account identifier of the GitOps Agent where argo project will exist.
        :param pulumi.Input[_builtins.str] agent_id: Agent identifier of the agent where argo project will exist (include scope prefix)
        :param pulumi.Input[_builtins.str] org_id: Org identifier of the GitOps Agent where argo project is to be created.
        :param pulumi.Input[_builtins.str] project_id: Project identifier of the Gitops Agent where argo project is to be created.
        :param pulumi.Input[Sequence[pulumi.Input[Union['GitopsAppProjectProjectArgs', 'GitopsAppProjectProjectArgsDict']]]] projects: GitOps project configuration.
        :param pulumi.Input[_builtins.str] query_name: Identifier for the GitOps Argo project.
        :param pulumi.Input[_builtins.bool] upsert: Indicates if the argo project should be updated if existing and inserted if not.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _GitopsAppProjectState.__new__(_GitopsAppProjectState)

        __props__.__dict__["account_id"] = account_id
        __props__.__dict__["agent_id"] = agent_id
        __props__.__dict__["org_id"] = org_id
        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["projects"] = projects
        __props__.__dict__["query_name"] = query_name
        __props__.__dict__["upsert"] = upsert
        return GitopsAppProject(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="accountId")
    @_utilities.deprecated("""This field is deprecated and will be removed in a future release.""")
    def account_id(self) -> pulumi.Output[_builtins.str]:
        """
        Account identifier of the GitOps Agent where argo project will exist.
        """
        return pulumi.get(self, "account_id")

    @_builtins.property
    @pulumi.getter(name="agentId")
    def agent_id(self) -> pulumi.Output[_builtins.str]:
        """
        Agent identifier of the agent where argo project will exist (include scope prefix)
        """
        return pulumi.get(self, "agent_id")

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Org identifier of the GitOps Agent where argo project is to be created.
        """
        return pulumi.get(self, "org_id")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Project identifier of the Gitops Agent where argo project is to be created.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter
    def projects(self) -> pulumi.Output[Sequence['outputs.GitopsAppProjectProject']]:
        """
        GitOps project configuration.
        """
        return pulumi.get(self, "projects")

    @_builtins.property
    @pulumi.getter(name="queryName")
    def query_name(self) -> pulumi.Output[_builtins.str]:
        """
        Identifier for the GitOps Argo project.
        """
        return pulumi.get(self, "query_name")

    @_builtins.property
    @pulumi.getter
    def upsert(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Indicates if the argo project should be updated if existing and inserted if not.
        """
        return pulumi.get(self, "upsert")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['SecurityGovernanceConditionArgs', 'SecurityGovernanceCondition']

@pulumi.input_type
class SecurityGovernanceConditionArgs:
    def __init__(__self__, *,
                 fault_spec: pulumi.Input['SecurityGovernanceConditionFaultSpecArgs'],
                 infra_type: pulumi.Input[_builtins.str],
                 org_id: pulumi.Input[_builtins.str],
                 project_id: pulumi.Input[_builtins.str],
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 k8s_spec: Optional[pulumi.Input['SecurityGovernanceConditionK8sSpecArgs']] = None,
                 machine_spec: Optional[pulumi.Input['SecurityGovernanceConditionMachineSpecArgs']] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None):
        """
        The set of arguments for constructing a SecurityGovernanceCondition resource.
        :param pulumi.Input['SecurityGovernanceConditionFaultSpecArgs'] fault_spec: Specification for faults to be included in the condition
        :param pulumi.Input[_builtins.str] infra_type: Type of infrastructure (Kubernetes, KubernetesV2, Linux, Windows, CloudFoundry, Container)
        :param pulumi.Input[_builtins.str] org_id: The organization ID of the security governance condition
        :param pulumi.Input[_builtins.str] project_id: The project ID of the security governance condition
        :param pulumi.Input[_builtins.str] description: Description of the security governance condition
        :param pulumi.Input['SecurityGovernanceConditionK8sSpecArgs'] k8s_spec: Kubernetes specific configuration (required when infra*type is KUBERNETES or KUBERNETESV2)
        :param pulumi.Input['SecurityGovernanceConditionMachineSpecArgs'] machine_spec: Machine specific configuration (required when infra*type is LINUX or WINDOWS)
        :param pulumi.Input[_builtins.str] name: Name of the security governance condition
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags for the security governance condition
        """
        pulumi.set(__self__, "fault_spec", fault_spec)
        pulumi.set(__self__, "infra_type", infra_type)
        pulumi.set(__self__, "org_id", org_id)
        pulumi.set(__self__, "project_id", project_id)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if k8s_spec is not None:
            pulumi.set(__self__, "k8s_spec", k8s_spec)
        if machine_spec is not None:
            pulumi.set(__self__, "machine_spec", machine_spec)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @_builtins.property
    @pulumi.getter(name="faultSpec")
    def fault_spec(self) -> pulumi.Input['SecurityGovernanceConditionFaultSpecArgs']:
        """
        Specification for faults to be included in the condition
        """
        return pulumi.get(self, "fault_spec")

    @fault_spec.setter
    def fault_spec(self, value: pulumi.Input['SecurityGovernanceConditionFaultSpecArgs']):
        pulumi.set(self, "fault_spec", value)

    @_builtins.property
    @pulumi.getter(name="infraType")
    def infra_type(self) -> pulumi.Input[_builtins.str]:
        """
        Type of infrastructure (Kubernetes, KubernetesV2, Linux, Windows, CloudFoundry, Container)
        """
        return pulumi.get(self, "infra_type")

    @infra_type.setter
    def infra_type(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "infra_type", value)

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> pulumi.Input[_builtins.str]:
        """
        The organization ID of the security governance condition
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "org_id", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Input[_builtins.str]:
        """
        The project ID of the security governance condition
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Description of the security governance condition
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="k8sSpec")
    def k8s_spec(self) -> Optional[pulumi.Input['SecurityGovernanceConditionK8sSpecArgs']]:
        """
        Kubernetes specific configuration (required when infra*type is KUBERNETES or KUBERNETESV2)
        """
        return pulumi.get(self, "k8s_spec")

    @k8s_spec.setter
    def k8s_spec(self, value: Optional[pulumi.Input['SecurityGovernanceConditionK8sSpecArgs']]):
        pulumi.set(self, "k8s_spec", value)

    @_builtins.property
    @pulumi.getter(name="machineSpec")
    def machine_spec(self) -> Optional[pulumi.Input['SecurityGovernanceConditionMachineSpecArgs']]:
        """
        Machine specific configuration (required when infra*type is LINUX or WINDOWS)
        """
        return pulumi.get(self, "machine_spec")

    @machine_spec.setter
    def machine_spec(self, value: Optional[pulumi.Input['SecurityGovernanceConditionMachineSpecArgs']]):
        pulumi.set(self, "machine_spec", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the security governance condition
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Tags for the security governance condition
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tags", value)


@pulumi.input_type
class _SecurityGovernanceConditionState:
    def __init__(__self__, *,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 fault_spec: Optional[pulumi.Input['SecurityGovernanceConditionFaultSpecArgs']] = None,
                 infra_type: Optional[pulumi.Input[_builtins.str]] = None,
                 k8s_spec: Optional[pulumi.Input['SecurityGovernanceConditionK8sSpecArgs']] = None,
                 machine_spec: Optional[pulumi.Input['SecurityGovernanceConditionMachineSpecArgs']] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None):
        """
        Input properties used for looking up and filtering SecurityGovernanceCondition resources.
        :param pulumi.Input[_builtins.str] description: Description of the security governance condition
        :param pulumi.Input['SecurityGovernanceConditionFaultSpecArgs'] fault_spec: Specification for faults to be included in the condition
        :param pulumi.Input[_builtins.str] infra_type: Type of infrastructure (Kubernetes, KubernetesV2, Linux, Windows, CloudFoundry, Container)
        :param pulumi.Input['SecurityGovernanceConditionK8sSpecArgs'] k8s_spec: Kubernetes specific configuration (required when infra*type is KUBERNETES or KUBERNETESV2)
        :param pulumi.Input['SecurityGovernanceConditionMachineSpecArgs'] machine_spec: Machine specific configuration (required when infra*type is LINUX or WINDOWS)
        :param pulumi.Input[_builtins.str] name: Name of the security governance condition
        :param pulumi.Input[_builtins.str] org_id: The organization ID of the security governance condition
        :param pulumi.Input[_builtins.str] project_id: The project ID of the security governance condition
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags for the security governance condition
        """
        if description is not None:
            pulumi.set(__self__, "description", description)
        if fault_spec is not None:
            pulumi.set(__self__, "fault_spec", fault_spec)
        if infra_type is not None:
            pulumi.set(__self__, "infra_type", infra_type)
        if k8s_spec is not None:
            pulumi.set(__self__, "k8s_spec", k8s_spec)
        if machine_spec is not None:
            pulumi.set(__self__, "machine_spec", machine_spec)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Description of the security governance condition
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="faultSpec")
    def fault_spec(self) -> Optional[pulumi.Input['SecurityGovernanceConditionFaultSpecArgs']]:
        """
        Specification for faults to be included in the condition
        """
        return pulumi.get(self, "fault_spec")

    @fault_spec.setter
    def fault_spec(self, value: Optional[pulumi.Input['SecurityGovernanceConditionFaultSpecArgs']]):
        pulumi.set(self, "fault_spec", value)

    @_builtins.property
    @pulumi.getter(name="infraType")
    def infra_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Type of infrastructure (Kubernetes, KubernetesV2, Linux, Windows, CloudFoundry, Container)
        """
        return pulumi.get(self, "infra_type")

    @infra_type.setter
    def infra_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "infra_type", value)

    @_builtins.property
    @pulumi.getter(name="k8sSpec")
    def k8s_spec(self) -> Optional[pulumi.Input['SecurityGovernanceConditionK8sSpecArgs']]:
        """
        Kubernetes specific configuration (required when infra*type is KUBERNETES or KUBERNETESV2)
        """
        return pulumi.get(self, "k8s_spec")

    @k8s_spec.setter
    def k8s_spec(self, value: Optional[pulumi.Input['SecurityGovernanceConditionK8sSpecArgs']]):
        pulumi.set(self, "k8s_spec", value)

    @_builtins.property
    @pulumi.getter(name="machineSpec")
    def machine_spec(self) -> Optional[pulumi.Input['SecurityGovernanceConditionMachineSpecArgs']]:
        """
        Machine specific configuration (required when infra*type is LINUX or WINDOWS)
        """
        return pulumi.get(self, "machine_spec")

    @machine_spec.setter
    def machine_spec(self, value: Optional[pulumi.Input['SecurityGovernanceConditionMachineSpecArgs']]):
        pulumi.set(self, "machine_spec", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the security governance condition
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The organization ID of the security governance condition
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "org_id", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The project ID of the security governance condition
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Tags for the security governance condition
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tags", value)


@pulumi.type_token("harness:chaos/securityGovernanceCondition:SecurityGovernanceCondition")
class SecurityGovernanceCondition(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 fault_spec: Optional[pulumi.Input[Union['SecurityGovernanceConditionFaultSpecArgs', 'SecurityGovernanceConditionFaultSpecArgsDict']]] = None,
                 infra_type: Optional[pulumi.Input[_builtins.str]] = None,
                 k8s_spec: Optional[pulumi.Input[Union['SecurityGovernanceConditionK8sSpecArgs', 'SecurityGovernanceConditionK8sSpecArgsDict']]] = None,
                 machine_spec: Optional[pulumi.Input[Union['SecurityGovernanceConditionMachineSpecArgs', 'SecurityGovernanceConditionMachineSpecArgsDict']]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 __props__=None):
        """
        Resource for managing a Harness Chaos Security Governance Condition

        ## Example Usage

        ```python
        import pulumi
        import pulumi_harness as harness

        # Example of a Kubernetes Security Governance Condition
        k8s_condition = harness.chaos.SecurityGovernanceCondition("k8s_condition",
            org_id=org_id,
            project_id=project_id,
            name="k8s-security-condition",
            description="Security governance condition for Kubernetes workloads",
            infra_type="KubernetesV2",
            fault_spec={
                "operator": "NOT_EQUAL_TO",
                "faults": [
                    {
                        "fault_type": "FAULT",
                        "name": "pod-delete",
                    },
                    {
                        "fault_type": "FAULT",
                        "name": "pod-dns",
                    },
                ],
            },
            k8s_spec={
                "infra_spec": {
                    "operator": "EQUAL_TO",
                    "infra_ids": [k8s_infra_id],
                },
                "application_spec": {
                    "operator": "EQUAL_TO",
                    "workloads": [{
                        "namespace": "default",
                        "kind": "deployment",
                        "label": "app=nginx",
                        "services": ["nginx-service"],
                        "application_map_id": "nginx-app",
                    }],
                },
                "chaos_service_account_spec": {
                    "operator": "EQUAL_TO",
                    "service_accounts": [
                        "default",
                        "chaos-service-account",
                    ],
                },
            },
            tags=[
                "env:prod",
                "team:security",
                "platform:k8s",
            ])
        # Example of a Windows Security Governance Condition
        windows_condition = harness.chaos.SecurityGovernanceCondition("windows_condition",
            org_id=org_id,
            project_id=project_id,
            name="windows-security-condition",
            description="Security governance condition for Windows hosts",
            infra_type="Windows",
            fault_spec={
                "operator": "NOT_EQUAL_TO",
                "faults": [
                    {
                        "fault_type": "FAULT",
                        "name": "process-kill",
                    },
                    {
                        "fault_type": "FAULT",
                        "name": "cpu-hog",
                    },
                ],
            },
            machine_spec={
                "infra_spec": {
                    "operator": "EQUAL_TO",
                    "infra_ids": [windows_infra_id],
                },
            },
            tags=[
                "env:prod",
                "team:security",
                "platform:windows",
            ])
        # Example of a Linux Security Governance Condition
        linux_condition = harness.chaos.SecurityGovernanceCondition("linux_condition",
            org_id=org_id,
            project_id=project_id,
            name="linux-security-condition",
            description="Security governance condition for Linux hosts",
            infra_type="Linux",
            fault_spec={
                "operator": "NOT_EQUAL_TO",
                "faults": [
                    {
                        "fault_type": "FAULT",
                        "name": "process-kill",
                    },
                    {
                        "fault_type": "FAULT",
                        "name": "memory-hog",
                    },
                ],
            },
            machine_spec={
                "infra_spec": {
                    "operator": "EQUAL_TO",
                    "infra_ids": [linux_infra_id],
                },
            },
            tags=[
                "env:prod",
                "team:security",
                "platform:linux",
            ])
        pulumi.export("k8sConditionId", k8s_condition.id)
        pulumi.export("windowsConditionId", windows_condition.id)
        pulumi.export("linuxConditionId", linux_condition.id)
        ```

        ## Import

        The `pulumi import` command can be used, for example:

        Import Project level Chaos Security Governance Condition

        ```sh
        $ pulumi import harness:chaos/securityGovernanceCondition:SecurityGovernanceCondition example org_id/project_id/condition_id
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] description: Description of the security governance condition
        :param pulumi.Input[Union['SecurityGovernanceConditionFaultSpecArgs', 'SecurityGovernanceConditionFaultSpecArgsDict']] fault_spec: Specification for faults to be included in the condition
        :param pulumi.Input[_builtins.str] infra_type: Type of infrastructure (Kubernetes, KubernetesV2, Linux, Windows, CloudFoundry, Container)
        :param pulumi.Input[Union['SecurityGovernanceConditionK8sSpecArgs', 'SecurityGovernanceConditionK8sSpecArgsDict']] k8s_spec: Kubernetes specific configuration (required when infra*type is KUBERNETES or KUBERNETESV2)
        :param pulumi.Input[Union['SecurityGovernanceConditionMachineSpecArgs', 'SecurityGovernanceConditionMachineSpecArgsDict']] machine_spec: Machine specific configuration (required when infra*type is LINUX or WINDOWS)
        :param pulumi.Input[_builtins.str] name: Name of the security governance condition
        :param pulumi.Input[_builtins.str] org_id: The organization ID of the security governance condition
        :param pulumi.Input[_builtins.str] project_id: The project ID of the security governance condition
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags for the security governance condition
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: SecurityGovernanceConditionArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Resource for managing a Harness Chaos Security Governance Condition

        ## Example Usage

        ```python
        import pulumi
        import pulumi_harness as harness

        # Example of a Kubernetes Security Governance Condition
        k8s_condition = harness.chaos.SecurityGovernanceCondition("k8s_condition",
            org_id=org_id,
            project_id=project_id,
            name="k8s-security-condition",
            description="Security governance condition for Kubernetes workloads",
            infra_type="KubernetesV2",
            fault_spec={
                "operator": "NOT_EQUAL_TO",
                "faults": [
                    {
                        "fault_type": "FAULT",
                        "name": "pod-delete",
                    },
                    {
                        "fault_type": "FAULT",
                        "name": "pod-dns",
                    },
                ],
            },
            k8s_spec={
                "infra_spec": {
                    "operator": "EQUAL_TO",
                    "infra_ids": [k8s_infra_id],
                },
                "application_spec": {
                    "operator": "EQUAL_TO",
                    "workloads": [{
                        "namespace": "default",
                        "kind": "deployment",
                        "label": "app=nginx",
                        "services": ["nginx-service"],
                        "application_map_id": "nginx-app",
                    }],
                },
                "chaos_service_account_spec": {
                    "operator": "EQUAL_TO",
                    "service_accounts": [
                        "default",
                        "chaos-service-account",
                    ],
                },
            },
            tags=[
                "env:prod",
                "team:security",
                "platform:k8s",
            ])
        # Example of a Windows Security Governance Condition
        windows_condition = harness.chaos.SecurityGovernanceCondition("windows_condition",
            org_id=org_id,
            project_id=project_id,
            name="windows-security-condition",
            description="Security governance condition for Windows hosts",
            infra_type="Windows",
            fault_spec={
                "operator": "NOT_EQUAL_TO",
                "faults": [
                    {
                        "fault_type": "FAULT",
                        "name": "process-kill",
                    },
                    {
                        "fault_type": "FAULT",
                        "name": "cpu-hog",
                    },
                ],
            },
            machine_spec={
                "infra_spec": {
                    "operator": "EQUAL_TO",
                    "infra_ids": [windows_infra_id],
                },
            },
            tags=[
                "env:prod",
                "team:security",
                "platform:windows",
            ])
        # Example of a Linux Security Governance Condition
        linux_condition = harness.chaos.SecurityGovernanceCondition("linux_condition",
            org_id=org_id,
            project_id=project_id,
            name="linux-security-condition",
            description="Security governance condition for Linux hosts",
            infra_type="Linux",
            fault_spec={
                "operator": "NOT_EQUAL_TO",
                "faults": [
                    {
                        "fault_type": "FAULT",
                        "name": "process-kill",
                    },
                    {
                        "fault_type": "FAULT",
                        "name": "memory-hog",
                    },
                ],
            },
            machine_spec={
                "infra_spec": {
                    "operator": "EQUAL_TO",
                    "infra_ids": [linux_infra_id],
                },
            },
            tags=[
                "env:prod",
                "team:security",
                "platform:linux",
            ])
        pulumi.export("k8sConditionId", k8s_condition.id)
        pulumi.export("windowsConditionId", windows_condition.id)
        pulumi.export("linuxConditionId", linux_condition.id)
        ```

        ## Import

        The `pulumi import` command can be used, for example:

        Import Project level Chaos Security Governance Condition

        ```sh
        $ pulumi import harness:chaos/securityGovernanceCondition:SecurityGovernanceCondition example org_id/project_id/condition_id
        ```

        :param str resource_name: The name of the resource.
        :param SecurityGovernanceConditionArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(SecurityGovernanceConditionArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 fault_spec: Optional[pulumi.Input[Union['SecurityGovernanceConditionFaultSpecArgs', 'SecurityGovernanceConditionFaultSpecArgsDict']]] = None,
                 infra_type: Optional[pulumi.Input[_builtins.str]] = None,
                 k8s_spec: Optional[pulumi.Input[Union['SecurityGovernanceConditionK8sSpecArgs', 'SecurityGovernanceConditionK8sSpecArgsDict']]] = None,
                 machine_spec: Optional[pulumi.Input[Union['SecurityGovernanceConditionMachineSpecArgs', 'SecurityGovernanceConditionMachineSpecArgsDict']]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = SecurityGovernanceConditionArgs.__new__(SecurityGovernanceConditionArgs)

            __props__.__dict__["description"] = description
            if fault_spec is None and not opts.urn:
                raise TypeError("Missing required property 'fault_spec'")
            __props__.__dict__["fault_spec"] = fault_spec
            if infra_type is None and not opts.urn:
                raise TypeError("Missing required property 'infra_type'")
            __props__.__dict__["infra_type"] = infra_type
            __props__.__dict__["k8s_spec"] = k8s_spec
            __props__.__dict__["machine_spec"] = machine_spec
            __props__.__dict__["name"] = name
            if org_id is None and not opts.urn:
                raise TypeError("Missing required property 'org_id'")
            __props__.__dict__["org_id"] = org_id
            if project_id is None and not opts.urn:
                raise TypeError("Missing required property 'project_id'")
            __props__.__dict__["project_id"] = project_id
            __props__.__dict__["tags"] = tags
        super(SecurityGovernanceCondition, __self__).__init__(
            'harness:chaos/securityGovernanceCondition:SecurityGovernanceCondition',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            fault_spec: Optional[pulumi.Input[Union['SecurityGovernanceConditionFaultSpecArgs', 'SecurityGovernanceConditionFaultSpecArgsDict']]] = None,
            infra_type: Optional[pulumi.Input[_builtins.str]] = None,
            k8s_spec: Optional[pulumi.Input[Union['SecurityGovernanceConditionK8sSpecArgs', 'SecurityGovernanceConditionK8sSpecArgsDict']]] = None,
            machine_spec: Optional[pulumi.Input[Union['SecurityGovernanceConditionMachineSpecArgs', 'SecurityGovernanceConditionMachineSpecArgsDict']]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            org_id: Optional[pulumi.Input[_builtins.str]] = None,
            project_id: Optional[pulumi.Input[_builtins.str]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None) -> 'SecurityGovernanceCondition':
        """
        Get an existing SecurityGovernanceCondition resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] description: Description of the security governance condition
        :param pulumi.Input[Union['SecurityGovernanceConditionFaultSpecArgs', 'SecurityGovernanceConditionFaultSpecArgsDict']] fault_spec: Specification for faults to be included in the condition
        :param pulumi.Input[_builtins.str] infra_type: Type of infrastructure (Kubernetes, KubernetesV2, Linux, Windows, CloudFoundry, Container)
        :param pulumi.Input[Union['SecurityGovernanceConditionK8sSpecArgs', 'SecurityGovernanceConditionK8sSpecArgsDict']] k8s_spec: Kubernetes specific configuration (required when infra*type is KUBERNETES or KUBERNETESV2)
        :param pulumi.Input[Union['SecurityGovernanceConditionMachineSpecArgs', 'SecurityGovernanceConditionMachineSpecArgsDict']] machine_spec: Machine specific configuration (required when infra*type is LINUX or WINDOWS)
        :param pulumi.Input[_builtins.str] name: Name of the security governance condition
        :param pulumi.Input[_builtins.str] org_id: The organization ID of the security governance condition
        :param pulumi.Input[_builtins.str] project_id: The project ID of the security governance condition
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags for the security governance condition
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _SecurityGovernanceConditionState.__new__(_SecurityGovernanceConditionState)

        __props__.__dict__["description"] = description
        __props__.__dict__["fault_spec"] = fault_spec
        __props__.__dict__["infra_type"] = infra_type
        __props__.__dict__["k8s_spec"] = k8s_spec
        __props__.__dict__["machine_spec"] = machine_spec
        __props__.__dict__["name"] = name
        __props__.__dict__["org_id"] = org_id
        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["tags"] = tags
        return SecurityGovernanceCondition(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Description of the security governance condition
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter(name="faultSpec")
    def fault_spec(self) -> pulumi.Output['outputs.SecurityGovernanceConditionFaultSpec']:
        """
        Specification for faults to be included in the condition
        """
        return pulumi.get(self, "fault_spec")

    @_builtins.property
    @pulumi.getter(name="infraType")
    def infra_type(self) -> pulumi.Output[_builtins.str]:
        """
        Type of infrastructure (Kubernetes, KubernetesV2, Linux, Windows, CloudFoundry, Container)
        """
        return pulumi.get(self, "infra_type")

    @_builtins.property
    @pulumi.getter(name="k8sSpec")
    def k8s_spec(self) -> pulumi.Output[Optional['outputs.SecurityGovernanceConditionK8sSpec']]:
        """
        Kubernetes specific configuration (required when infra*type is KUBERNETES or KUBERNETESV2)
        """
        return pulumi.get(self, "k8s_spec")

    @_builtins.property
    @pulumi.getter(name="machineSpec")
    def machine_spec(self) -> pulumi.Output[Optional['outputs.SecurityGovernanceConditionMachineSpec']]:
        """
        Machine specific configuration (required when infra*type is LINUX or WINDOWS)
        """
        return pulumi.get(self, "machine_spec")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        Name of the security governance condition
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> pulumi.Output[_builtins.str]:
        """
        The organization ID of the security governance condition
        """
        return pulumi.get(self, "org_id")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[_builtins.str]:
        """
        The project ID of the security governance condition
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        Tags for the security governance condition
        """
        return pulumi.get(self, "tags")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['EncryptedTextArgs', 'EncryptedText']

@pulumi.input_type
class EncryptedTextArgs:
    def __init__(__self__, *,
                 secret_manager_id: pulumi.Input[_builtins.str],
                 inherit_scopes_from_secret_manager: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 scoped_to_account: Optional[pulumi.Input[_builtins.bool]] = None,
                 secret_reference: Optional[pulumi.Input[_builtins.str]] = None,
                 usage_scopes: Optional[pulumi.Input[Sequence[pulumi.Input['EncryptedTextUsageScopeArgs']]]] = None,
                 value: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a EncryptedText resource.
        :param pulumi.Input[_builtins.str] secret_manager_id: The id of the secret manager to associate the secret with. Once set, this field cannot be changed.
        :param pulumi.Input[_builtins.bool] inherit_scopes_from_secret_manager: Boolean that indicates whether or not to inherit the usage scopes from the secret manager
        :param pulumi.Input[_builtins.str] name: Name of the encrypted text secret
        :param pulumi.Input[_builtins.bool] scoped_to_account: Boolean that indicates whether or not the secret is scoped to the account
        :param pulumi.Input[_builtins.str] secret_reference: Name of the existing secret. If you already have secrets created in a secrets manager such as HashiCorp Vault or AWS Secrets Manager, you do not need to re-create the existing secrets in Harness.
        :param pulumi.Input[Sequence[pulumi.Input['EncryptedTextUsageScopeArgs']]] usage_scopes: This block is used for scoping the resource to a specific set of applications or environments.
        :param pulumi.Input[_builtins.str] value: The value of the secret.
        """
        pulumi.set(__self__, "secret_manager_id", secret_manager_id)
        if inherit_scopes_from_secret_manager is not None:
            pulumi.set(__self__, "inherit_scopes_from_secret_manager", inherit_scopes_from_secret_manager)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if scoped_to_account is not None:
            pulumi.set(__self__, "scoped_to_account", scoped_to_account)
        if secret_reference is not None:
            pulumi.set(__self__, "secret_reference", secret_reference)
        if usage_scopes is not None:
            pulumi.set(__self__, "usage_scopes", usage_scopes)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @_builtins.property
    @pulumi.getter(name="secretManagerId")
    def secret_manager_id(self) -> pulumi.Input[_builtins.str]:
        """
        The id of the secret manager to associate the secret with. Once set, this field cannot be changed.
        """
        return pulumi.get(self, "secret_manager_id")

    @secret_manager_id.setter
    def secret_manager_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "secret_manager_id", value)

    @_builtins.property
    @pulumi.getter(name="inheritScopesFromSecretManager")
    def inherit_scopes_from_secret_manager(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Boolean that indicates whether or not to inherit the usage scopes from the secret manager
        """
        return pulumi.get(self, "inherit_scopes_from_secret_manager")

    @inherit_scopes_from_secret_manager.setter
    def inherit_scopes_from_secret_manager(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "inherit_scopes_from_secret_manager", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the encrypted text secret
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="scopedToAccount")
    def scoped_to_account(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Boolean that indicates whether or not the secret is scoped to the account
        """
        return pulumi.get(self, "scoped_to_account")

    @scoped_to_account.setter
    def scoped_to_account(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "scoped_to_account", value)

    @_builtins.property
    @pulumi.getter(name="secretReference")
    def secret_reference(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the existing secret. If you already have secrets created in a secrets manager such as HashiCorp Vault or AWS Secrets Manager, you do not need to re-create the existing secrets in Harness.
        """
        return pulumi.get(self, "secret_reference")

    @secret_reference.setter
    def secret_reference(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "secret_reference", value)

    @_builtins.property
    @pulumi.getter(name="usageScopes")
    def usage_scopes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['EncryptedTextUsageScopeArgs']]]]:
        """
        This block is used for scoping the resource to a specific set of applications or environments.
        """
        return pulumi.get(self, "usage_scopes")

    @usage_scopes.setter
    def usage_scopes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['EncryptedTextUsageScopeArgs']]]]):
        pulumi.set(self, "usage_scopes", value)

    @_builtins.property
    @pulumi.getter
    def value(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The value of the secret.
        """
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "value", value)


@pulumi.input_type
class _EncryptedTextState:
    def __init__(__self__, *,
                 inherit_scopes_from_secret_manager: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 scoped_to_account: Optional[pulumi.Input[_builtins.bool]] = None,
                 secret_manager_id: Optional[pulumi.Input[_builtins.str]] = None,
                 secret_reference: Optional[pulumi.Input[_builtins.str]] = None,
                 usage_scopes: Optional[pulumi.Input[Sequence[pulumi.Input['EncryptedTextUsageScopeArgs']]]] = None,
                 value: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering EncryptedText resources.
        :param pulumi.Input[_builtins.bool] inherit_scopes_from_secret_manager: Boolean that indicates whether or not to inherit the usage scopes from the secret manager
        :param pulumi.Input[_builtins.str] name: Name of the encrypted text secret
        :param pulumi.Input[_builtins.bool] scoped_to_account: Boolean that indicates whether or not the secret is scoped to the account
        :param pulumi.Input[_builtins.str] secret_manager_id: The id of the secret manager to associate the secret with. Once set, this field cannot be changed.
        :param pulumi.Input[_builtins.str] secret_reference: Name of the existing secret. If you already have secrets created in a secrets manager such as HashiCorp Vault or AWS Secrets Manager, you do not need to re-create the existing secrets in Harness.
        :param pulumi.Input[Sequence[pulumi.Input['EncryptedTextUsageScopeArgs']]] usage_scopes: This block is used for scoping the resource to a specific set of applications or environments.
        :param pulumi.Input[_builtins.str] value: The value of the secret.
        """
        if inherit_scopes_from_secret_manager is not None:
            pulumi.set(__self__, "inherit_scopes_from_secret_manager", inherit_scopes_from_secret_manager)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if scoped_to_account is not None:
            pulumi.set(__self__, "scoped_to_account", scoped_to_account)
        if secret_manager_id is not None:
            pulumi.set(__self__, "secret_manager_id", secret_manager_id)
        if secret_reference is not None:
            pulumi.set(__self__, "secret_reference", secret_reference)
        if usage_scopes is not None:
            pulumi.set(__self__, "usage_scopes", usage_scopes)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @_builtins.property
    @pulumi.getter(name="inheritScopesFromSecretManager")
    def inherit_scopes_from_secret_manager(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Boolean that indicates whether or not to inherit the usage scopes from the secret manager
        """
        return pulumi.get(self, "inherit_scopes_from_secret_manager")

    @inherit_scopes_from_secret_manager.setter
    def inherit_scopes_from_secret_manager(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "inherit_scopes_from_secret_manager", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the encrypted text secret
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="scopedToAccount")
    def scoped_to_account(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Boolean that indicates whether or not the secret is scoped to the account
        """
        return pulumi.get(self, "scoped_to_account")

    @scoped_to_account.setter
    def scoped_to_account(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "scoped_to_account", value)

    @_builtins.property
    @pulumi.getter(name="secretManagerId")
    def secret_manager_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The id of the secret manager to associate the secret with. Once set, this field cannot be changed.
        """
        return pulumi.get(self, "secret_manager_id")

    @secret_manager_id.setter
    def secret_manager_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "secret_manager_id", value)

    @_builtins.property
    @pulumi.getter(name="secretReference")
    def secret_reference(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the existing secret. If you already have secrets created in a secrets manager such as HashiCorp Vault or AWS Secrets Manager, you do not need to re-create the existing secrets in Harness.
        """
        return pulumi.get(self, "secret_reference")

    @secret_reference.setter
    def secret_reference(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "secret_reference", value)

    @_builtins.property
    @pulumi.getter(name="usageScopes")
    def usage_scopes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['EncryptedTextUsageScopeArgs']]]]:
        """
        This block is used for scoping the resource to a specific set of applications or environments.
        """
        return pulumi.get(self, "usage_scopes")

    @usage_scopes.setter
    def usage_scopes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['EncryptedTextUsageScopeArgs']]]]):
        pulumi.set(self, "usage_scopes", value)

    @_builtins.property
    @pulumi.getter
    def value(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The value of the secret.
        """
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "value", value)


@pulumi.type_token("harness:index/encryptedText:EncryptedText")
class EncryptedText(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 inherit_scopes_from_secret_manager: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 scoped_to_account: Optional[pulumi.Input[_builtins.bool]] = None,
                 secret_manager_id: Optional[pulumi.Input[_builtins.str]] = None,
                 secret_reference: Optional[pulumi.Input[_builtins.str]] = None,
                 usage_scopes: Optional[pulumi.Input[Sequence[pulumi.Input[Union['EncryptedTextUsageScopeArgs', 'EncryptedTextUsageScopeArgsDict']]]]] = None,
                 value: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Resource for creating an encrypted text secret

        ## Example Usage

        ```python
        import pulumi
        import pulumi_harness as harness

        default = harness.get_secret_manager(default=True)
        example = harness.EncryptedText("example",
            name="example-secret",
            value="someval",
            secret_manager_id=default.id,
            usage_scopes=[
                {
                    "environment_filter_type": "PRODUCTION_ENVIRONMENTS",
                },
                {
                    "environment_filter_type": "NON_PRODUCTION_ENVIRONMENTS",
                },
            ])
        ```

        ## Import

        The `pulumi import` command can be used, for example:

        Import using the Harness encrypted text format.

        NOTE: The secret value cannot be decrypted and imported.

        ```sh
        $ pulumi import harness:index/encryptedText:EncryptedText example <secret_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.bool] inherit_scopes_from_secret_manager: Boolean that indicates whether or not to inherit the usage scopes from the secret manager
        :param pulumi.Input[_builtins.str] name: Name of the encrypted text secret
        :param pulumi.Input[_builtins.bool] scoped_to_account: Boolean that indicates whether or not the secret is scoped to the account
        :param pulumi.Input[_builtins.str] secret_manager_id: The id of the secret manager to associate the secret with. Once set, this field cannot be changed.
        :param pulumi.Input[_builtins.str] secret_reference: Name of the existing secret. If you already have secrets created in a secrets manager such as HashiCorp Vault or AWS Secrets Manager, you do not need to re-create the existing secrets in Harness.
        :param pulumi.Input[Sequence[pulumi.Input[Union['EncryptedTextUsageScopeArgs', 'EncryptedTextUsageScopeArgsDict']]]] usage_scopes: This block is used for scoping the resource to a specific set of applications or environments.
        :param pulumi.Input[_builtins.str] value: The value of the secret.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: EncryptedTextArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Resource for creating an encrypted text secret

        ## Example Usage

        ```python
        import pulumi
        import pulumi_harness as harness

        default = harness.get_secret_manager(default=True)
        example = harness.EncryptedText("example",
            name="example-secret",
            value="someval",
            secret_manager_id=default.id,
            usage_scopes=[
                {
                    "environment_filter_type": "PRODUCTION_ENVIRONMENTS",
                },
                {
                    "environment_filter_type": "NON_PRODUCTION_ENVIRONMENTS",
                },
            ])
        ```

        ## Import

        The `pulumi import` command can be used, for example:

        Import using the Harness encrypted text format.

        NOTE: The secret value cannot be decrypted and imported.

        ```sh
        $ pulumi import harness:index/encryptedText:EncryptedText example <secret_id>
        ```

        :param str resource_name: The name of the resource.
        :param EncryptedTextArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(EncryptedTextArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 inherit_scopes_from_secret_manager: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 scoped_to_account: Optional[pulumi.Input[_builtins.bool]] = None,
                 secret_manager_id: Optional[pulumi.Input[_builtins.str]] = None,
                 secret_reference: Optional[pulumi.Input[_builtins.str]] = None,
                 usage_scopes: Optional[pulumi.Input[Sequence[pulumi.Input[Union['EncryptedTextUsageScopeArgs', 'EncryptedTextUsageScopeArgsDict']]]]] = None,
                 value: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = EncryptedTextArgs.__new__(EncryptedTextArgs)

            __props__.__dict__["inherit_scopes_from_secret_manager"] = inherit_scopes_from_secret_manager
            __props__.__dict__["name"] = name
            __props__.__dict__["scoped_to_account"] = scoped_to_account
            if secret_manager_id is None and not opts.urn:
                raise TypeError("Missing required property 'secret_manager_id'")
            __props__.__dict__["secret_manager_id"] = secret_manager_id
            __props__.__dict__["secret_reference"] = secret_reference
            __props__.__dict__["usage_scopes"] = usage_scopes
            __props__.__dict__["value"] = None if value is None else pulumi.Output.secret(value)
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["value"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(EncryptedText, __self__).__init__(
            'harness:index/encryptedText:EncryptedText',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            inherit_scopes_from_secret_manager: Optional[pulumi.Input[_builtins.bool]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            scoped_to_account: Optional[pulumi.Input[_builtins.bool]] = None,
            secret_manager_id: Optional[pulumi.Input[_builtins.str]] = None,
            secret_reference: Optional[pulumi.Input[_builtins.str]] = None,
            usage_scopes: Optional[pulumi.Input[Sequence[pulumi.Input[Union['EncryptedTextUsageScopeArgs', 'EncryptedTextUsageScopeArgsDict']]]]] = None,
            value: Optional[pulumi.Input[_builtins.str]] = None) -> 'EncryptedText':
        """
        Get an existing EncryptedText resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.bool] inherit_scopes_from_secret_manager: Boolean that indicates whether or not to inherit the usage scopes from the secret manager
        :param pulumi.Input[_builtins.str] name: Name of the encrypted text secret
        :param pulumi.Input[_builtins.bool] scoped_to_account: Boolean that indicates whether or not the secret is scoped to the account
        :param pulumi.Input[_builtins.str] secret_manager_id: The id of the secret manager to associate the secret with. Once set, this field cannot be changed.
        :param pulumi.Input[_builtins.str] secret_reference: Name of the existing secret. If you already have secrets created in a secrets manager such as HashiCorp Vault or AWS Secrets Manager, you do not need to re-create the existing secrets in Harness.
        :param pulumi.Input[Sequence[pulumi.Input[Union['EncryptedTextUsageScopeArgs', 'EncryptedTextUsageScopeArgsDict']]]] usage_scopes: This block is used for scoping the resource to a specific set of applications or environments.
        :param pulumi.Input[_builtins.str] value: The value of the secret.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _EncryptedTextState.__new__(_EncryptedTextState)

        __props__.__dict__["inherit_scopes_from_secret_manager"] = inherit_scopes_from_secret_manager
        __props__.__dict__["name"] = name
        __props__.__dict__["scoped_to_account"] = scoped_to_account
        __props__.__dict__["secret_manager_id"] = secret_manager_id
        __props__.__dict__["secret_reference"] = secret_reference
        __props__.__dict__["usage_scopes"] = usage_scopes
        __props__.__dict__["value"] = value
        return EncryptedText(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="inheritScopesFromSecretManager")
    def inherit_scopes_from_secret_manager(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Boolean that indicates whether or not to inherit the usage scopes from the secret manager
        """
        return pulumi.get(self, "inherit_scopes_from_secret_manager")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        Name of the encrypted text secret
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="scopedToAccount")
    def scoped_to_account(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Boolean that indicates whether or not the secret is scoped to the account
        """
        return pulumi.get(self, "scoped_to_account")

    @_builtins.property
    @pulumi.getter(name="secretManagerId")
    def secret_manager_id(self) -> pulumi.Output[_builtins.str]:
        """
        The id of the secret manager to associate the secret with. Once set, this field cannot be changed.
        """
        return pulumi.get(self, "secret_manager_id")

    @_builtins.property
    @pulumi.getter(name="secretReference")
    def secret_reference(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Name of the existing secret. If you already have secrets created in a secrets manager such as HashiCorp Vault or AWS Secrets Manager, you do not need to re-create the existing secrets in Harness.
        """
        return pulumi.get(self, "secret_reference")

    @_builtins.property
    @pulumi.getter(name="usageScopes")
    def usage_scopes(self) -> pulumi.Output[Optional[Sequence['outputs.EncryptedTextUsageScope']]]:
        """
        This block is used for scoping the resource to a specific set of applications or environments.
        """
        return pulumi.get(self, "usage_scopes")

    @_builtins.property
    @pulumi.getter
    def value(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The value of the secret.
        """
        return pulumi.get(self, "value")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetDelegatetokenResult',
    'AwaitableGetDelegatetokenResult',
    'get_delegatetoken',
    'get_delegatetoken_output',
]

@pulumi.output_type
class GetDelegatetokenResult:
    """
    A collection of values returned by getDelegatetoken.
    """
    def __init__(__self__, account_id=None, created_at=None, created_by=None, id=None, name=None, org_id=None, project_id=None, revoke_after=None, token_status=None, value=None):
        if account_id and not isinstance(account_id, str):
            raise TypeError("Expected argument 'account_id' to be a str")
        pulumi.set(__self__, "account_id", account_id)
        if created_at and not isinstance(created_at, int):
            raise TypeError("Expected argument 'created_at' to be a int")
        pulumi.set(__self__, "created_at", created_at)
        if created_by and not isinstance(created_by, dict):
            raise TypeError("Expected argument 'created_by' to be a dict")
        pulumi.set(__self__, "created_by", created_by)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if org_id and not isinstance(org_id, str):
            raise TypeError("Expected argument 'org_id' to be a str")
        pulumi.set(__self__, "org_id", org_id)
        if project_id and not isinstance(project_id, str):
            raise TypeError("Expected argument 'project_id' to be a str")
        pulumi.set(__self__, "project_id", project_id)
        if revoke_after and not isinstance(revoke_after, int):
            raise TypeError("Expected argument 'revoke_after' to be a int")
        pulumi.set(__self__, "revoke_after", revoke_after)
        if token_status and not isinstance(token_status, str):
            raise TypeError("Expected argument 'token_status' to be a str")
        pulumi.set(__self__, "token_status", token_status)
        if value and not isinstance(value, str):
            raise TypeError("Expected argument 'value' to be a str")
        pulumi.set(__self__, "value", value)

    @_builtins.property
    @pulumi.getter(name="accountId")
    def account_id(self) -> _builtins.str:
        """
        Account Identifier for the Entity
        """
        return pulumi.get(self, "account_id")

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> _builtins.int:
        """
        Time when the delegate token is created. This is an epoch timestamp.
        """
        return pulumi.get(self, "created_at")

    @_builtins.property
    @pulumi.getter(name="createdBy")
    def created_by(self) -> Mapping[str, _builtins.str]:
        """
        created by details
        """
        return pulumi.get(self, "created_by")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        Name of the delegate token
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[_builtins.str]:
        """
        Org Identifier for the Entity
        """
        return pulumi.get(self, "org_id")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[_builtins.str]:
        """
        Project Identifier for the Entity
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter(name="revokeAfter")
    def revoke_after(self) -> _builtins.int:
        """
        Epoch time in milliseconds after which the token will be marked as revoked. There can be a delay of up to one hour from the epoch value provided and actual revoking of the token.
        """
        return pulumi.get(self, "revoke_after")

    @_builtins.property
    @pulumi.getter(name="tokenStatus")
    def token_status(self) -> Optional[_builtins.str]:
        """
        Status of Delegate Token (ACTIVE or REVOKED). If left empty both active and revoked tokens will be assumed
        """
        return pulumi.get(self, "token_status")

    @_builtins.property
    @pulumi.getter
    def value(self) -> _builtins.str:
        """
        Value of the delegate token. Encoded in base64.
        """
        return pulumi.get(self, "value")


class AwaitableGetDelegatetokenResult(GetDelegatetokenResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetDelegatetokenResult(
            account_id=self.account_id,
            created_at=self.created_at,
            created_by=self.created_by,
            id=self.id,
            name=self.name,
            org_id=self.org_id,
            project_id=self.project_id,
            revoke_after=self.revoke_after,
            token_status=self.token_status,
            value=self.value)


def get_delegatetoken(account_id: Optional[_builtins.str] = None,
                      name: Optional[_builtins.str] = None,
                      org_id: Optional[_builtins.str] = None,
                      project_id: Optional[_builtins.str] = None,
                      token_status: Optional[_builtins.str] = None,
                      opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetDelegatetokenResult:
    """
    Data source for retrieving a Harness delegate Token.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_harness as harness

    # Look up a delegate token at account level by name
    account_level = harness.platform.get_delegatetoken(name="account-delegate-token",
        account_id="account_id")
    # Look up a delegate token at organization level
    org_level = harness.platform.get_delegatetoken(name="org-delegate-token",
        account_id="account_id",
        org_id="org_id")
    # Look up a delegate token at project level
    project_level = harness.platform.get_delegatetoken(name="project-delegate-token",
        account_id="account_id",
        org_id="org_id",
        project_id="project_id")
    ```


    :param _builtins.str account_id: Account Identifier for the Entity
    :param _builtins.str name: Name of the delegate token
    :param _builtins.str org_id: Org Identifier for the Entity
    :param _builtins.str project_id: Project Identifier for the Entity
    :param _builtins.str token_status: Status of Delegate Token (ACTIVE or REVOKED). If left empty both active and revoked tokens will be assumed
    """
    __args__ = dict()
    __args__['accountId'] = account_id
    __args__['name'] = name
    __args__['orgId'] = org_id
    __args__['projectId'] = project_id
    __args__['tokenStatus'] = token_status
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('harness:platform/getDelegatetoken:getDelegatetoken', __args__, opts=opts, typ=GetDelegatetokenResult).value

    return AwaitableGetDelegatetokenResult(
        account_id=pulumi.get(__ret__, 'account_id'),
        created_at=pulumi.get(__ret__, 'created_at'),
        created_by=pulumi.get(__ret__, 'created_by'),
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'),
        org_id=pulumi.get(__ret__, 'org_id'),
        project_id=pulumi.get(__ret__, 'project_id'),
        revoke_after=pulumi.get(__ret__, 'revoke_after'),
        token_status=pulumi.get(__ret__, 'token_status'),
        value=pulumi.get(__ret__, 'value'))
def get_delegatetoken_output(account_id: Optional[pulumi.Input[_builtins.str]] = None,
                             name: Optional[pulumi.Input[_builtins.str]] = None,
                             org_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                             project_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                             token_status: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                             opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetDelegatetokenResult]:
    """
    Data source for retrieving a Harness delegate Token.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_harness as harness

    # Look up a delegate token at account level by name
    account_level = harness.platform.get_delegatetoken(name="account-delegate-token",
        account_id="account_id")
    # Look up a delegate token at organization level
    org_level = harness.platform.get_delegatetoken(name="org-delegate-token",
        account_id="account_id",
        org_id="org_id")
    # Look up a delegate token at project level
    project_level = harness.platform.get_delegatetoken(name="project-delegate-token",
        account_id="account_id",
        org_id="org_id",
        project_id="project_id")
    ```


    :param _builtins.str account_id: Account Identifier for the Entity
    :param _builtins.str name: Name of the delegate token
    :param _builtins.str org_id: Org Identifier for the Entity
    :param _builtins.str project_id: Project Identifier for the Entity
    :param _builtins.str token_status: Status of Delegate Token (ACTIVE or REVOKED). If left empty both active and revoked tokens will be assumed
    """
    __args__ = dict()
    __args__['accountId'] = account_id
    __args__['name'] = name
    __args__['orgId'] = org_id
    __args__['projectId'] = project_id
    __args__['tokenStatus'] = token_status
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('harness:platform/getDelegatetoken:getDelegatetoken', __args__, opts=opts, typ=GetDelegatetokenResult)
    return __ret__.apply(lambda __response__: GetDelegatetokenResult(
        account_id=pulumi.get(__response__, 'account_id'),
        created_at=pulumi.get(__response__, 'created_at'),
        created_by=pulumi.get(__response__, 'created_by'),
        id=pulumi.get(__response__, 'id'),
        name=pulumi.get(__response__, 'name'),
        org_id=pulumi.get(__response__, 'org_id'),
        project_id=pulumi.get(__response__, 'project_id'),
        revoke_after=pulumi.get(__response__, 'revoke_after'),
        token_status=pulumi.get(__response__, 'token_status'),
        value=pulumi.get(__response__, 'value')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetIdpCatalogEntityResult',
    'AwaitableGetIdpCatalogEntityResult',
    'get_idp_catalog_entity',
    'get_idp_catalog_entity_output',
]

@pulumi.output_type
class GetIdpCatalogEntityResult:
    """
    A collection of values returned by getIdpCatalogEntity.
    """
    def __init__(__self__, git_details=None, id=None, identifier=None, kind=None, org_id=None, project_id=None, yaml=None):
        if git_details and not isinstance(git_details, list):
            raise TypeError("Expected argument 'git_details' to be a list")
        pulumi.set(__self__, "git_details", git_details)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if identifier and not isinstance(identifier, str):
            raise TypeError("Expected argument 'identifier' to be a str")
        pulumi.set(__self__, "identifier", identifier)
        if kind and not isinstance(kind, str):
            raise TypeError("Expected argument 'kind' to be a str")
        pulumi.set(__self__, "kind", kind)
        if org_id and not isinstance(org_id, str):
            raise TypeError("Expected argument 'org_id' to be a str")
        pulumi.set(__self__, "org_id", org_id)
        if project_id and not isinstance(project_id, str):
            raise TypeError("Expected argument 'project_id' to be a str")
        pulumi.set(__self__, "project_id", project_id)
        if yaml and not isinstance(yaml, str):
            raise TypeError("Expected argument 'yaml' to be a str")
        pulumi.set(__self__, "yaml", yaml)

    @_builtins.property
    @pulumi.getter(name="gitDetails")
    def git_details(self) -> Sequence['outputs.GetIdpCatalogEntityGitDetailResult']:
        """
        Contains Git Information for importing entities from Git
        """
        return pulumi.get(self, "git_details")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> _builtins.str:
        """
        Unique identifier of the resource.
        """
        return pulumi.get(self, "identifier")

    @_builtins.property
    @pulumi.getter
    def kind(self) -> _builtins.str:
        """
        Kind of the catalog entity
        """
        return pulumi.get(self, "kind")

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[_builtins.str]:
        """
        Unique identifier of the organization.
        """
        return pulumi.get(self, "org_id")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[_builtins.str]:
        """
        Unique identifier of the project.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter
    def yaml(self) -> _builtins.str:
        """
        YAML definition of the catalog entity
        """
        return pulumi.get(self, "yaml")


class AwaitableGetIdpCatalogEntityResult(GetIdpCatalogEntityResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetIdpCatalogEntityResult(
            git_details=self.git_details,
            id=self.id,
            identifier=self.identifier,
            kind=self.kind,
            org_id=self.org_id,
            project_id=self.project_id,
            yaml=self.yaml)


def get_idp_catalog_entity(identifier: Optional[_builtins.str] = None,
                           kind: Optional[_builtins.str] = None,
                           org_id: Optional[_builtins.str] = None,
                           project_id: Optional[_builtins.str] = None,
                           opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetIdpCatalogEntityResult:
    """
    Data source for retrieving Harness catalog entities.


    :param _builtins.str identifier: Unique identifier of the resource.
    :param _builtins.str kind: Kind of the catalog entity
    :param _builtins.str org_id: Unique identifier of the organization.
    :param _builtins.str project_id: Unique identifier of the project.
    """
    __args__ = dict()
    __args__['identifier'] = identifier
    __args__['kind'] = kind
    __args__['orgId'] = org_id
    __args__['projectId'] = project_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('harness:platform/getIdpCatalogEntity:getIdpCatalogEntity', __args__, opts=opts, typ=GetIdpCatalogEntityResult).value

    return AwaitableGetIdpCatalogEntityResult(
        git_details=pulumi.get(__ret__, 'git_details'),
        id=pulumi.get(__ret__, 'id'),
        identifier=pulumi.get(__ret__, 'identifier'),
        kind=pulumi.get(__ret__, 'kind'),
        org_id=pulumi.get(__ret__, 'org_id'),
        project_id=pulumi.get(__ret__, 'project_id'),
        yaml=pulumi.get(__ret__, 'yaml'))
def get_idp_catalog_entity_output(identifier: Optional[pulumi.Input[_builtins.str]] = None,
                                  kind: Optional[pulumi.Input[_builtins.str]] = None,
                                  org_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                  project_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                  opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetIdpCatalogEntityResult]:
    """
    Data source for retrieving Harness catalog entities.


    :param _builtins.str identifier: Unique identifier of the resource.
    :param _builtins.str kind: Kind of the catalog entity
    :param _builtins.str org_id: Unique identifier of the organization.
    :param _builtins.str project_id: Unique identifier of the project.
    """
    __args__ = dict()
    __args__['identifier'] = identifier
    __args__['kind'] = kind
    __args__['orgId'] = org_id
    __args__['projectId'] = project_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('harness:platform/getIdpCatalogEntity:getIdpCatalogEntity', __args__, opts=opts, typ=GetIdpCatalogEntityResult)
    return __ret__.apply(lambda __response__: GetIdpCatalogEntityResult(
        git_details=pulumi.get(__response__, 'git_details'),
        id=pulumi.get(__response__, 'id'),
        identifier=pulumi.get(__response__, 'identifier'),
        kind=pulumi.get(__response__, 'kind'),
        org_id=pulumi.get(__response__, 'org_id'),
        project_id=pulumi.get(__response__, 'project_id'),
        yaml=pulumi.get(__response__, 'yaml')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetGcpProjectsResult',
    'AwaitableGetGcpProjectsResult',
    'get_gcp_projects',
    'get_gcp_projects_output',
]

@pulumi.output_type
class GetGcpProjectsResult:
    """
    A collection of values returned by getGcpProjects.
    """
    def __init__(__self__, connector_id=None, id=None, org_id=None, project_id=None, projects=None):
        if connector_id and not isinstance(connector_id, str):
            raise TypeError("Expected argument 'connector_id' to be a str")
        pulumi.set(__self__, "connector_id", connector_id)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if org_id and not isinstance(org_id, str):
            raise TypeError("Expected argument 'org_id' to be a str")
        pulumi.set(__self__, "org_id", org_id)
        if project_id and not isinstance(project_id, str):
            raise TypeError("Expected argument 'project_id' to be a str")
        pulumi.set(__self__, "project_id", project_id)
        if projects and not isinstance(projects, list):
            raise TypeError("Expected argument 'projects' to be a list")
        pulumi.set(__self__, "projects", projects)

    @_builtins.property
    @pulumi.getter(name="connectorId")
    def connector_id(self) -> _builtins.str:
        """
        Identifier of the GCP cloud connector or secret manager connector.
        """
        return pulumi.get(self, "connector_id")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[_builtins.str]:
        """
        Unique identifier of the organization.
        """
        return pulumi.get(self, "org_id")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[_builtins.str]:
        """
        Unique identifier of the project.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter
    def projects(self) -> Sequence['outputs.GetGcpProjectsProjectResult']:
        return pulumi.get(self, "projects")


class AwaitableGetGcpProjectsResult(GetGcpProjectsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetGcpProjectsResult(
            connector_id=self.connector_id,
            id=self.id,
            org_id=self.org_id,
            project_id=self.project_id,
            projects=self.projects)


def get_gcp_projects(connector_id: Optional[_builtins.str] = None,
                     org_id: Optional[_builtins.str] = None,
                     project_id: Optional[_builtins.str] = None,
                     opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetGcpProjectsResult:
    """
    Data source for listing GCP projects using a cloud connector identifier or secret manager connector identifier.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_harness as harness

    # Example: List GCP projects using a GCP cloud connector
    example = harness.platform.get_gcp_projects(connector_id="my_gcp_connector")
    # Example: List GCP projects using a GCP secret manager connector
    example_secret_manager = harness.platform.get_gcp_projects(connector_id="my_gcp_secret_manager_connector")
    # Example: List GCP projects with org and project scope
    example_scoped = harness.platform.get_gcp_projects(connector_id="my_gcp_connector",
        org_id="my_org",
        project_id="my_project")
    pulumi.export("gcpProjects", example.projects)
    ```


    :param _builtins.str connector_id: Identifier of the GCP cloud connector or secret manager connector.
    :param _builtins.str org_id: Unique identifier of the organization.
    :param _builtins.str project_id: Unique identifier of the project.
    """
    __args__ = dict()
    __args__['connectorId'] = connector_id
    __args__['orgId'] = org_id
    __args__['projectId'] = project_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('harness:platform/getGcpProjects:getGcpProjects', __args__, opts=opts, typ=GetGcpProjectsResult).value

    return AwaitableGetGcpProjectsResult(
        connector_id=pulumi.get(__ret__, 'connector_id'),
        id=pulumi.get(__ret__, 'id'),
        org_id=pulumi.get(__ret__, 'org_id'),
        project_id=pulumi.get(__ret__, 'project_id'),
        projects=pulumi.get(__ret__, 'projects'))
def get_gcp_projects_output(connector_id: Optional[pulumi.Input[_builtins.str]] = None,
                            org_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                            project_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                            opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetGcpProjectsResult]:
    """
    Data source for listing GCP projects using a cloud connector identifier or secret manager connector identifier.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_harness as harness

    # Example: List GCP projects using a GCP cloud connector
    example = harness.platform.get_gcp_projects(connector_id="my_gcp_connector")
    # Example: List GCP projects using a GCP secret manager connector
    example_secret_manager = harness.platform.get_gcp_projects(connector_id="my_gcp_secret_manager_connector")
    # Example: List GCP projects with org and project scope
    example_scoped = harness.platform.get_gcp_projects(connector_id="my_gcp_connector",
        org_id="my_org",
        project_id="my_project")
    pulumi.export("gcpProjects", example.projects)
    ```


    :param _builtins.str connector_id: Identifier of the GCP cloud connector or secret manager connector.
    :param _builtins.str org_id: Unique identifier of the organization.
    :param _builtins.str project_id: Unique identifier of the project.
    """
    __args__ = dict()
    __args__['connectorId'] = connector_id
    __args__['orgId'] = org_id
    __args__['projectId'] = project_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('harness:platform/getGcpProjects:getGcpProjects', __args__, opts=opts, typ=GetGcpProjectsResult)
    return __ret__.apply(lambda __response__: GetGcpProjectsResult(
        connector_id=pulumi.get(__response__, 'connector_id'),
        id=pulumi.get(__response__, 'id'),
        org_id=pulumi.get(__response__, 'org_id'),
        project_id=pulumi.get(__response__, 'project_id'),
        projects=pulumi.get(__response__, 'projects')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['SloArgs', 'Slo']

@pulumi.input_type
class SloArgs:
    def __init__(__self__, *,
                 identifier: pulumi.Input[_builtins.str],
                 org_id: pulumi.Input[_builtins.str],
                 project_id: pulumi.Input[_builtins.str],
                 request: Optional[pulumi.Input['SloRequestArgs']] = None):
        """
        The set of arguments for constructing a Slo resource.
        :param pulumi.Input[_builtins.str] identifier: Identifier of the SLO.
        :param pulumi.Input[_builtins.str] org_id: Identifier of the organization in which the SLO is configured.
        :param pulumi.Input[_builtins.str] project_id: Identifier of the project in which the SLO is configured.
        :param pulumi.Input['SloRequestArgs'] request: Request for creating or updating SLO.
        """
        pulumi.set(__self__, "identifier", identifier)
        pulumi.set(__self__, "org_id", org_id)
        pulumi.set(__self__, "project_id", project_id)
        if request is not None:
            pulumi.set(__self__, "request", request)

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> pulumi.Input[_builtins.str]:
        """
        Identifier of the SLO.
        """
        return pulumi.get(self, "identifier")

    @identifier.setter
    def identifier(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "identifier", value)

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> pulumi.Input[_builtins.str]:
        """
        Identifier of the organization in which the SLO is configured.
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "org_id", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Input[_builtins.str]:
        """
        Identifier of the project in which the SLO is configured.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter
    def request(self) -> Optional[pulumi.Input['SloRequestArgs']]:
        """
        Request for creating or updating SLO.
        """
        return pulumi.get(self, "request")

    @request.setter
    def request(self, value: Optional[pulumi.Input['SloRequestArgs']]):
        pulumi.set(self, "request", value)


@pulumi.input_type
class _SloState:
    def __init__(__self__, *,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 request: Optional[pulumi.Input['SloRequestArgs']] = None):
        """
        Input properties used for looking up and filtering Slo resources.
        :param pulumi.Input[_builtins.str] identifier: Identifier of the SLO.
        :param pulumi.Input[_builtins.str] org_id: Identifier of the organization in which the SLO is configured.
        :param pulumi.Input[_builtins.str] project_id: Identifier of the project in which the SLO is configured.
        :param pulumi.Input['SloRequestArgs'] request: Request for creating or updating SLO.
        """
        if identifier is not None:
            pulumi.set(__self__, "identifier", identifier)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if request is not None:
            pulumi.set(__self__, "request", request)

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Identifier of the SLO.
        """
        return pulumi.get(self, "identifier")

    @identifier.setter
    def identifier(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "identifier", value)

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Identifier of the organization in which the SLO is configured.
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "org_id", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Identifier of the project in which the SLO is configured.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter
    def request(self) -> Optional[pulumi.Input['SloRequestArgs']]:
        """
        Request for creating or updating SLO.
        """
        return pulumi.get(self, "request")

    @request.setter
    def request(self, value: Optional[pulumi.Input['SloRequestArgs']]):
        pulumi.set(self, "request", value)


@pulumi.type_token("harness:platform/slo:Slo")
class Slo(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 request: Optional[pulumi.Input[Union['SloRequestArgs', 'SloRequestArgsDict']]] = None,
                 __props__=None):
        """
        Resource for creating an SLO.

        ## Example Usage

        ```python
        import pulumi
        import json
        import pulumi_harness as harness

        example = harness.platform.Slo("example",
            org_id="org_id",
            project_id="project_id",
            identifier="identifier",
            request={
                "name": "name",
                "description": "description",
                "tags": [
                    "foo:bar",
                    "bar:foo",
                ],
                "user_journey_refs": [
                    "one",
                    "two",
                ],
                "slo_target": {
                    "type": "Calender",
                    "slo_target_percentage": 10,
                    "spec": json.dumps({
                        "type": "Monthly",
                        "spec": {
                            "dayOfMonth": 5,
                        },
                    }),
                },
                "type": "Simple",
                "spec": json.dumps({
                    "monitoredServiceRef": "monitoredServiceRef",
                    "serviceLevelIndicatorType": "Availability",
                    "serviceLevelIndicators": [{
                        "name": "name",
                        "identifier": "identifier",
                        "type": "Window",
                        "spec": {
                            "type": "Threshold",
                            "spec": {
                                "metric1": "metric1",
                                "thresholdValue": 10,
                                "thresholdType": ">",
                            },
                            "sliMissingDataType": "Good",
                        },
                    }],
                }),
                "notification_rule_refs": [{
                    "notification_rule_ref": "notification_rule_ref",
                    "enabled": True,
                }],
            })
        ```

        ## Import

        The `pulumi import` command can be used, for example:

        Import account level SLO

        ```sh
        $ pulumi import harness:platform/slo:Slo example <slo_id>
        ```

        Import organization level SLO

        ```sh
        $ pulumi import harness:platform/slo:Slo example <org_id>/<slo_id>
        ```

        Import project level SLO

        ```sh
        $ pulumi import harness:platform/slo:Slo example <org_id>/<project_id>/<slo_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] identifier: Identifier of the SLO.
        :param pulumi.Input[_builtins.str] org_id: Identifier of the organization in which the SLO is configured.
        :param pulumi.Input[_builtins.str] project_id: Identifier of the project in which the SLO is configured.
        :param pulumi.Input[Union['SloRequestArgs', 'SloRequestArgsDict']] request: Request for creating or updating SLO.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: SloArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Resource for creating an SLO.

        ## Example Usage

        ```python
        import pulumi
        import json
        import pulumi_harness as harness

        example = harness.platform.Slo("example",
            org_id="org_id",
            project_id="project_id",
            identifier="identifier",
            request={
                "name": "name",
                "description": "description",
                "tags": [
                    "foo:bar",
                    "bar:foo",
                ],
                "user_journey_refs": [
                    "one",
                    "two",
                ],
                "slo_target": {
                    "type": "Calender",
                    "slo_target_percentage": 10,
                    "spec": json.dumps({
                        "type": "Monthly",
                        "spec": {
                            "dayOfMonth": 5,
                        },
                    }),
                },
                "type": "Simple",
                "spec": json.dumps({
                    "monitoredServiceRef": "monitoredServiceRef",
                    "serviceLevelIndicatorType": "Availability",
                    "serviceLevelIndicators": [{
                        "name": "name",
                        "identifier": "identifier",
                        "type": "Window",
                        "spec": {
                            "type": "Threshold",
                            "spec": {
                                "metric1": "metric1",
                                "thresholdValue": 10,
                                "thresholdType": ">",
                            },
                            "sliMissingDataType": "Good",
                        },
                    }],
                }),
                "notification_rule_refs": [{
                    "notification_rule_ref": "notification_rule_ref",
                    "enabled": True,
                }],
            })
        ```

        ## Import

        The `pulumi import` command can be used, for example:

        Import account level SLO

        ```sh
        $ pulumi import harness:platform/slo:Slo example <slo_id>
        ```

        Import organization level SLO

        ```sh
        $ pulumi import harness:platform/slo:Slo example <org_id>/<slo_id>
        ```

        Import project level SLO

        ```sh
        $ pulumi import harness:platform/slo:Slo example <org_id>/<project_id>/<slo_id>
        ```

        :param str resource_name: The name of the resource.
        :param SloArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(SloArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 request: Optional[pulumi.Input[Union['SloRequestArgs', 'SloRequestArgsDict']]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = SloArgs.__new__(SloArgs)

            if identifier is None and not opts.urn:
                raise TypeError("Missing required property 'identifier'")
            __props__.__dict__["identifier"] = identifier
            if org_id is None and not opts.urn:
                raise TypeError("Missing required property 'org_id'")
            __props__.__dict__["org_id"] = org_id
            if project_id is None and not opts.urn:
                raise TypeError("Missing required property 'project_id'")
            __props__.__dict__["project_id"] = project_id
            __props__.__dict__["request"] = request
        super(Slo, __self__).__init__(
            'harness:platform/slo:Slo',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            identifier: Optional[pulumi.Input[_builtins.str]] = None,
            org_id: Optional[pulumi.Input[_builtins.str]] = None,
            project_id: Optional[pulumi.Input[_builtins.str]] = None,
            request: Optional[pulumi.Input[Union['SloRequestArgs', 'SloRequestArgsDict']]] = None) -> 'Slo':
        """
        Get an existing Slo resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] identifier: Identifier of the SLO.
        :param pulumi.Input[_builtins.str] org_id: Identifier of the organization in which the SLO is configured.
        :param pulumi.Input[_builtins.str] project_id: Identifier of the project in which the SLO is configured.
        :param pulumi.Input[Union['SloRequestArgs', 'SloRequestArgsDict']] request: Request for creating or updating SLO.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _SloState.__new__(_SloState)

        __props__.__dict__["identifier"] = identifier
        __props__.__dict__["org_id"] = org_id
        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["request"] = request
        return Slo(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> pulumi.Output[_builtins.str]:
        """
        Identifier of the SLO.
        """
        return pulumi.get(self, "identifier")

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> pulumi.Output[_builtins.str]:
        """
        Identifier of the organization in which the SLO is configured.
        """
        return pulumi.get(self, "org_id")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[_builtins.str]:
        """
        Identifier of the project in which the SLO is configured.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter
    def request(self) -> pulumi.Output[Optional['outputs.SloRequest']]:
        """
        Request for creating or updating SLO.
        """
        return pulumi.get(self, "request")

